#!/bin/sh
#--------------------------------------------------------------------
# fwupdatepost
#--------------------------------------------------------------------

FWUPDATEPOST_DONE=/fwupdate_done
POSTUPDATE_RUNNING=/tmp/fwupdatepost.run
FWUPDATE_LOG=/fwupdate.log

if [ -f $FWUPDATE_LOG ]; then
	echo "Already executed ..."
	exit 0
fi

PATH=/sbin:/usr/sbin:/bin:/usr/bin:$PATH
export PATH

#check 1st argument, if exist, run argv1
if [ $# -eq 1 ]; then
	[ -x $1 ] && $1
fi

/bin/touch $POSTUPDATE_RUNNING

SYFT_SIZE=0

function get_syft_length()
{
	SYFT_ID=$1
#	echo syft id $SYFT_ID
	SIZE=`/usr/sbin/fuc -d | /bin/grep ^${SYFT_ID} | /usr/bin/awk '{print $3}' | /bin/sed 's/0x//g'`
	SYFT_SIZE=$((16#${SIZE}))	
#	echo syft size $SIZE
}

function write_log_msg()
{
	echo >> $FWUPDATE_LOG
	date >> $FWUPDATE_LOG
	echo "$1" >> $FWUPDATE_LOG
}

function cmd_out_log()
{
	echo >> $FWUPDATE_LOG
	date >> $FWUPDATE_LOG
	$1 >> $FWUPDATE_LOG
}

echo
echo "Start making the new rootfs ..."

write_log_msg "Start fwupdatepost.sh"

OLDMTD=`/bin/cat /proc/driver/sy_basic_conf | /bin/grep BOOTMTD | /bin/sed -e 's/^BOOTMTD=//g' -e 's/;$//g'`

echo "Checking mtd device ..."
[ "$OLDMTD" -ne "11" ] && [ "$OLDMTD" -ne "12" ] && exit 0

echo "  Current mtd : ${OLDMTD}"
if [ $OLDMTD -eq 11 ]; then
	ROOTMTD=12
else
	ROOTMTD=11
fi
echo "  New mtd : ${ROOTMTD}"

write_log_msg "  New mtd : ${ROOTMTD}"

# 20111212
rm -rf /usr/local/share/snmp
rm -rf /lib/*snmp* /opt/nss/bin/snmp*
rm -rf /web/*.cap

MTD=mtd$ROOTMTD
RFSMTD=/dev/mtd$ROOTMTD
RFSMTDBLOCK=/dev/mtdblock$ROOTMTD

RI_MTD=/dev/mtd4
SI_MTD=/dev/mtd5
WI_MTD=/dev/mtd6
CI_MTD=/dev/mtd7
FES_MTD=/dev/mtd8

RI_IMG=/ri.tar.gz
SI_IMG=/si.tar.gz
WI_IMG=/wi.tar.gz
CI_IMG=/ci.tar.gz
FES_IMG=/fes.tar.gz

echo "Erase rootfs mtd ..."
# erase rootfs mtd
/usr/sbin/flash_eraseall $RFSMTD

write_log_msg "Erase rootfs mtd"

echo "Mount rootfs mtd ..."
/bin/mount -t yaffs2 $RFSMTDBLOCK /mnt/nand

cmd_out_log /bin/mount
cmd_out_log "/bin/df -h"

cd /mnt/nand

# Rootfs Image
get_syft_length 01
RI_SIZE=$SYFT_SIZE
echo ri size $RI_SIZE
if [ $RI_SIZE -gt 0 ]; then
	write_log_msg "Extract RI size=$RI_SIZE"
	/usr/sbin/nanddump -o -B -l $RI_SIZE -f $RI_IMG $RI_MTD
	/bin/tar xzf $RI_IMG
	rm $RI_IMG
	sync
	cmd_out_log "/bin/df -h"
fi

# System Image
get_syft_length 02
SI_SIZE=$SYFT_SIZE
echo si size $SI_SIZE
if [ $SI_SIZE -gt 0 ]; then
	write_log_msg "Extract SI size=$SI_SIZE"
	/usr/sbin/nanddump -o -B -l $SI_SIZE -f $SI_IMG $SI_MTD
	/bin/tar xzf $SI_IMG
	rm $SI_IMG
	sync
	cmd_out_log "/bin/df -h"
fi

# Web Image
get_syft_length 03
WI_SIZE=$SYFT_SIZE
echo wi size $WI_SIZE
if [ $WI_SIZE -gt 0 ]; then
	write_log_msg "Extract WI size=$WI_SIZE"
	/usr/sbin/nanddump -o -B -l $WI_SIZE -f $WI_IMG $WI_MTD
	/bin/tar xzf $WI_IMG
	rm $WI_IMG
	sync
	cmd_out_log "/bin/df -h"
fi

# Make default config
DEF_CFG=etc/default_conf.tgz
echo -n "Make default config  "
. etc/sysconfig/_conf.list
/bin/tar czf $DEF_CFG $FILES_TO_COMPRESS
echo "[ Done ]"
write_log_msg "Make default config"

# Config Image
get_syft_length 04
CI_SIZE=$SYFT_SIZE
echo ci size $CI_SIZE
if [ $CI_SIZE -gt 0 ]; then
	write_log_msg "Extract CI size=$CI_SIZE"
	/usr/sbin/nanddump -o -B -l $CI_SIZE -f $CI_IMG $CI_MTD
	/bin/tar xzf $CI_IMG
	rm $CI_IMG
	sync
	cmd_out_log "/bin/df -h"
fi

# FES(5i) Image
get_syft_length 05
FES_SIZE=$SYFT_SIZE
echo FES size $FES_SIZE
if [ $FES_SIZE -gt 0 ]; then
	write_log_msg "Extract FES size=$FES_SIZE"
	/usr/sbin/nanddump -o -B -l $FES_SIZE -f $FES_IMG $FES_MTD
	/bin/tar xzf $FES_IMG
	rm $FES_IMG
	sync
	cmd_out_log "/bin/df -h"
fi

/usr/sbin/fuc -sh sft-config offset=18 data=$ROOTMTD

/bin/touch $FWUPDATEPOST_DONE

cd /
/bin/sync
/bin/sleep 1
/bin/sync
/bin/umount $RFSMTDBLOCK

rm $POSTUPDATE_RUNNING

write_log_msg "End of fwupdatepost.sh"

exit 0
